<?php
// $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/es.php,v 1.19 2004/06/07 13:01:28 uugdave Exp $


// Search form
$lang['simple_search_form_str'] = 'Formulario de bsqueda sencilla';
$lang['advanced_search_form_str'] = 'Formulario de bsqueda avanzada';
$lang['server'] = 'Servidor';
$lang['search_for_entries_whose'] = 'Buscar objetos los cuales';
$lang['base_dn'] = 'DN Base';
$lang['search_scope'] = 'Alcance de la bsqueda';
$lang['search_ filter'] = 'Filtro de Bsqueda';
$lang['show_attributes'] = 'Mostrar atributos';
$lang['Search'] = 'Buscar';
$lang['equals'] = 'equivale';
$lang['starts_with'] = 'comienza con';
$lang['contains'] = 'contiene';
$lang['ends_with'] = 'termina con';
$lang['sounds_like'] = 'suena como';

// Tree browser
$lang['request_new_feature'] = 'Pedir funcionalidad';
$lang['see_open_requests'] = 'Ver las peticiones';
$lang['report_bug'] = 'Reportar un error';
$lang['see_open_bugs'] = 'Ver los errores';
$lang['schema'] = 'esquema';
$lang['search'] = 'buscar';
$lang['create'] = 'crear';
$lang['info'] = 'info';
$lang['import'] = 'importar';
$lang['refresh'] = 'refrescar';
$lang['logout'] = 'salir';
$lang['create_new'] = 'Crear Nuevo Objeto';
$lang['view_schema_for'] = 'Ver esquema para';
$lang['refresh_expanded_containers'] = 'Refrescar todos los contenedores extendidos para';
$lang['create_new_entry_on'] = 'Crear nuevo objeto en';
$lang['view_server_info'] = 'Ver informacin del servidor';
$lang['import_from_ldif'] = 'Importar objetos de archivo LDIF';
$lang['logout_of_this_server'] = 'Salir de este servidor';
$lang['logged_in_as'] = 'Conectado como: ';
$lang['read_only'] = 'inalterable';
$lang['could_not_determine_root'] = 'No se ha podido determinar la raiz del servidor LDAP.';
$lang['ldap_refuses_to_give_root'] = 'Parece ser que el servidor LDAP se ha configurado para no revelar su raiz.';
$lang['please_specify_in_config'] = 'Por favor especifcala en el archivo config.php';
$lang['create_new_entry_in'] = 'Crear un nuevo objeto en';
$lang['login_link'] = 'Autenticacin...';

// Entry display
$lang['delete_this_entry'] = 'Borrar este objeto';
$lang['delete_this_entry_tooltip'] = 'Se tendr que confirmar esta decision';
$lang['copy_this_entry'] = 'Copiar este objeto';
$lang['copy_this_entry_tooltip'] = 'Copiar este objeto para otra localizacin, DN nuevo, o para otro servidor.';
$lang['export_to_ldif'] = 'Exportar archivo LDIF';
$lang['export_to_ldif_tooltip'] = 'Guardar archivo LDIF de este objeto';
$lang['export_subtree_to_ldif_tooltip'] = 'Guardar archivo LDIF de este objeto i todos sus objetos hijos';
$lang['export_subtree_to_ldif'] = 'Exportar archivo LDIF de sub-estructura';
$lang['export_mac'] = 'Avance de lnea de Macintosh';
$lang['export_win'] = 'Avance de lnea de Windows';
$lang['export_unix'] = 'Avance de lnea de Unix';
$lang['create_a_child_entry'] = 'Crear objeto como hijo';
$lang['add_a_jpeg_photo'] = 'Agregar jpegPhoto';
$lang['rename_entry'] = 'Renombrar objeto';
$lang['rename'] = 'Renombrar';
$lang['add'] = 'Agregar';
$lang['view'] = 'Ver';
$lang['add_new_attribute'] = 'Agregar nuevo atributo';
$lang['add_new_attribute_tooltip'] = 'Agregar nuevo atributo/valor a este objeto';
$lang['internal_attributes'] = 'Atributos Internos';
$lang['hide_internal_attrs'] = 'ocultar los atributos internos';
$lang['show_internal_attrs'] = 'mostrar els atributos internos';
$lang['internal_attrs_tooltip'] = 'Los atributos fijos automaticamente para el servidor';
$lang['entry_attributes'] = 'Atributos del objeto';
$lang['attr_name_tooltip'] = 'Haz click para ver la definicion del esquema para tipos de atributo \'%s\'';
$lang['click_to_display'] = 'Haz click para mostrar';
$lang['hidden'] = 'ocultado';
$lang['none'] = 'ninguno';
$lang['save_changes'] = 'Guardar los cambios';
$lang['add_value'] = 'agregar valor';
$lang['add_value_tooltip'] = 'Agregar valor adicional a este atributo';
$lang['refresh_entry'] = 'Refrescar';
$lang['refresh_this_entry'] = 'Refrescar este objeto';
$lang['delete_hint'] = 'Pista: <b>Para borrar un atributo</b>, vaca el formulario de texto y haz click en Guardar.';
$lang['attr_schema_hint'] = 'Pista: <b>Para ver el esquema de un atributo</b>, haz click en el nombre del atributo.';
$lang['attrs_modified'] = 'Algunos atributos (%s) fueron modificados y estan remarcados ms abajo.';
$lang['attr_modified'] = 'Un atributo (%s) fu modificado y est remarcado ms abajo.';
$lang['viewing_read_only'] = 'Mostrando el objeto en modo de no alterar.';
$lang['change_entry_rdn'] = 'Modificar el RDN de este objeto';
$lang['no_new_attrs_available'] = 'No hay atributos nuevos disponibles para este objeto';
$lang['binary_value'] = 'Valor binario';
$lang['add_new_binary_attr'] = 'Agregar valor binario';
$lang['add_new_binary_attr_tooltip'] = 'Agregar atributo/valor binario de un archivo';
$lang['alias_for'] = '%s es sinnimo para %s';
$lang['download_value'] = 'Descargar valor';
$lang['delete_attribute'] = 'Borrar atributo';
$lang['true'] = 'verdad';
$lang['false'] = 'falso';
$lang['none_remove_value'] = 'ningo, borrar valor';
$lang['really_delete_attribute'] = 'Borrar realmente el atributo?';

// Schema browser
$lang['the_following_objectclasses'] = 'Los siguientes <b>ObjectClass</b> estn presentes en este servidor LDAP.';
$lang['the_following_attributes'] = 'Los siguientes <b>attributeTypes</b> estn presentes en este servidor LDAP.';
$lang['the_following_matching'] = 'Los siguientes <b>matching rules</b> estn presentes en este servidor LDAP.';
$lang['the_following_syntaxes'] = 'Los siguientes <b>sintaxis</b> estn presentes en este servidor LDAP.'; 
$lang['jump_to_objectclass'] = 'Saltar a una ObjectClass';
$lang['jump_to_attr'] = 'Saltar a un atributo';
$lang['schema_for_server'] = 'Esquema del servidor ';
$lang['required_attrs'] = 'Atributos Requeridos (MUST)';
$lang['optional_attrs'] = 'Atributos Opcionales (MAY)';
$lang['OID'] = 'OID';
$lang['desc'] = 'Descripcin';
$lang['name'] = 'Nom';
$lang['is_obsolete'] = 'Esta ObjectClass es <b>obsoleta</b>';
$lang['inherits'] = 'Hereda';
$lang['jump_to_this_oclass'] = 'Saltar a esta ObjectClass';
$lang['matching_rule_oid'] = 'OID de Matching Rule';
$lang['syntax_oid'] = 'OID de Sintaxi';
$lang['not_applicable'] = 'no es aplicable';
$lang['not_specified'] = 'no especificada';

// Deleting entries
$lang['entry_deleted_successfully'] = 'Entrada \'%s\' borrada correctamente.';
$lang['you_must_specify_a_dn'] = 'Tienes que especificar un DN';
$lang['could_not_delete_entry'] = 'No he podido borrar la entrada: %s';

// Adding objectClass form
$lang['new_required_attrs'] = 'Nuevos atributos requeridos';
$lang['requires_to_add'] = 'Esta accin exige que se agreguen';
$lang['new_attributes'] = 'nuevos atributos';
$lang['new_required_attrs_instructions'] = 'Instrucciones: Para agregar esta ObjectClass a este objeto, se tiene que especificar';
$lang['that_this_oclass_requires'] = 'que este ObjectClass requiere. Se puede hacer con este formulario.';
$lang['add_oclass_and_attrs'] = 'Agregar ObjectClass y Atributos';

// General
$lang['chooser_link_tooltip'] = 'Haz click para seleccionar un objeto graficamente';
$lang['no_updates_in_read_only_mode'] = 'No se puede modificar el objeto si el servidor est operando en modo inalterable.';
$lang['bad_server_id'] = 'El identificador de servidor est mal';
$lang['not_enough_login_info'] = 'No tengo suficiente informacin para conectar al servidor. Por favor configura correctamente el archivo config.php';
$lang['could_not_connect'] = 'No se ha podido conectar al servidor LDAP';
$lang['could_not_perform_ldap_mod_add'] = 'No se ha podido ejecutar la operacin del ldap_mod_add.';
$lang['bad_server_id_underline'] = 'El identificador del servidor est mal: ';
$lang['success'] = 'Exito';
$lang['server_colon_pare'] = 'Servidor: ';
$lang['look_in'] = 'Buscando a: ';
$lang['missing_server_id_in_query_string'] = 'No est presente el identificador del servidor en la URL';
$lang['missing_dn_in_query_string'] = 'No est presente el DN en la URL';
$lang['back_up_p'] = 'Volver a...';
$lang['no_entries'] = 'no hay entradas';
$lang['not_logged_in'] = 'No ests autenticado';
$lang['could_not_det_base_dn'] = 'No he podido determinar la base DN';

// Add value form
$lang['add_new'] = 'Agregar';
$lang['value_to'] = 'valor a';
$lang['server'] = 'Servidor';
$lang['distinguished_name'] = 'Nombre distinguido';
$lang['current_list_of'] = 'La lista actual de';
$lang['values_for_attribute'] = 'valores para el atributo';
$lang['inappropriate_matching_note'] = 'Nota: Sino has configurado una regla \'EQUALITY\' en el servidor LDAP, recibirs un error \'inappropriate matching\'';
$lang['enter_value_to_add'] = 'Proveer el valor para agregar: ';
$lang['new_required_attrs_note'] = 'Nota: Es posible que se requiera agregar nuevos atributos para satisfacer los requisitos de esta ObjectClass';
$lang['syntax'] = 'Sintaxi';

//copy.php
$lang['copy_server_read_only'] = 'No se pueden realizar las modificaciones si el servidor est operando en modo inalterable';
$lang['copy_dest_dn_blank'] = 'No se ha rellenado el formulario de DN.';
$lang['copy_dest_already_exists'] = 'La entrada de destino (%s) encara existe.';
$lang['copy_dest_container_does_not_exist'] = 'El contenedor de destino (%s) no existe.';
$lang['copy_source_dest_dn_same'] = 'El DN de la fuente y el DN de destino son los mismos.';
$lang['copy_copying'] = 'Copiando ';
$lang['copy_recursive_copy_progress'] = 'El progreso de la copia recurrente';
$lang['copy_building_snapshot'] = 'Construyendo la \'foto\' del arbol para copiar... ';
$lang['copy_successful_like_to'] = 'Exito! Deseas ';
$lang['copy_view_new_entry'] = 'Ver el nuevo objeto?';
$lang['copy_failed'] = 'Error al copiar DN: '; 

//edit.php
$lang['missing_template_file'] = 'Error: falta la plantilla, ';
$lang['using_default'] = 'Usando el archivo por defecto.';

//copy_form.php
$lang['copyf_title_copy'] = 'Copiar ';
$lang['copyf_to_new_object'] = 'a un objeto nuevo';
$lang['copyf_dest_dn'] = 'DN de destino';
$lang['copyf_dest_dn_tooltip'] = 'El DN entero de la nueva entrada a ser creada quan se copie la entrada fuente';
$lang['copyf_dest_server'] = 'Servidor de destino';
$lang['copyf_note'] = 'Nota: Copiar entre dos servidores funciona solamente si no hay violaciones del esquema.';
$lang['copyf_recursive_copy'] = 'Borrar todos los hijos recurentemente tambin?';

//create.php
$lang['create_required_attribute'] = 'Te has dejado el valor en blanco del atributo requerido <b>%s</b>.';
$lang['create_redirecting'] = 'Redirigiendo';
$lang['create_here'] = 'aqu';
$lang['create_could_not_add'] = 'No he podido agregar el objeto al servidor LDAP.';

//create_form.php
$lang['createf_create_object'] = 'Crear Objeto';
$lang['createf_choose_temp'] = 'Escoge una plantilla';
$lang['createf_select_temp'] = 'Selecciona una plantilla para al proceso de creacin';
$lang['createf_proceed'] = 'Proceder';

//creation_template.php
$lang['ctemplate_on_server'] = 'Al servidor';
$lang['ctemplate_no_template'] = 'No se ha especificado ninguna plantilla en las variables del POST.';
$lang['ctemplate_config_handler'] = 'Tu configuracin especifica un manejador de';
$lang['ctemplate_handler_does_not_exist'] = 'para esta plantilla. Pero este manejador no existe en el directorio \'templates/creation\'.';

// search.php
$lang['you_have_not_logged_into_server'] = 'An no te has autenticado en ell servidor seleccionado, no puedes hacer ninguna bsqueda.';
$lang['click_to_go_to_login_form'] = 'Hac click aqu para ir al formulario de autenticacin';
$lang['unrecognized_criteria_option'] = 'Opcion de criterio desconocida: ';
$lang['if_you_want_to_add_criteria'] = 'Si quieres agregar tu propio criterio en la lista. Estate seguro de editar search.php para manejarlo. Saliendo.';
$lang['entries_found'] = 'Entrades encontradas: ';
$lang['filter_performed'] = 'Filtro realitzado: ';
$lang['search_duration'] = 'Bsqueda realitzada para phpLDAPadmin a';
$lang['seconds'] = 'segundos';

// search_form_advanced.php
$lang['scope_in_which_to_search'] = 'El alcance en el que buscar';
$lang['scope_sub'] = 'Sub (todo el sub-arbol)';
$lang['scope_one'] = 'Uno (un nivel por debajo de la base)';
$lang['scope_base'] = 'Base (solo base dn)';
$lang['standard_ldap_search_filter'] = 'Filtro de bsqueda estndar de LDAP. Ejemplo: (&(sn=Smith)(givenname=David))';
$lang['search_filter'] = 'Filtro de bsqueda';
$lang['list_of_attrs_to_display_in_results'] = 'Una lista de atributos para mostrar los resultados (separados por comas)';
$lang['show_attributes'] = 'Mostrar atributos';

// search_form_simple.php
$lang['search_for_entries_whose'] = 'Buscar entradas las cuales:';
$lang['equals'] = 'sea igual';
$lang['starts with'] = 'comience con';
$lang['contains'] = 'contenga';
$lang['ends with'] = 'termine con';
$lang['sounds like'] = 'suene como';
$lang['predefined_search_str'] = 'o seleccione uno de esta lista';

// server_info.php
$lang['could_not_fetch_server_info'] = 'No se ha podido sacar informacin LDAP del servidor';
$lang['server_info_for'] = 'Informacin del servidor para: ';
$lang['server_reports_following'] = 'El servidor muestra la siguiente informacin sobre el mismo';
$lang['nothing_to_report'] = 'Este servidor no tiene nada a mostrar.';

//update.php
$lang['update_array_malformed'] = 'el update_array est mal formado. Esto podra ser un error del phpLDAPadmin. Por favor reportalo.';
$lang['could_not_perform_ldap_modify'] = 'No he podido ejecutar la operacin ldap_modify.';

// update_confirm.php
$lang['do_you_want_to_make_these_changes'] = 'Quieres hacer estos cambios?';
$lang['attribute'] = 'Atributo';
$lang['old_value'] = 'Valor viejo';
$lang['new_value'] = 'Valor nuevo';
$lang['attr_deleted'] = '[atributo borrado]';
$lang['commit'] = 'Cometer';
$lang['cancel'] = 'Cancelar';
$lang['you_made_no_changes'] = 'No has hecho ningn cambio';
$lang['go_back'] = 'Volver atrs';

// welcome.php
$lang['welcome_note'] = 'Usa el men de la izquierda para navegar';
$lang['credits'] = "Crditos";
$lang['changelog'] = "Histrico de cambios";
$lang['documentation'] = "Documentacin";


// view_jpeg_photo.php
$lang['unsafe_file_name'] = 'Nombre de archivo inseguro: ';
$lang['no_such_file'] = 'Archivo inexistente: ';

//function.php
$lang['auto_update_not_setup'] = 'Has activado los auto_uid_numbers para <b>%s</b> en tu configuracin,
                                  pero no has especificado el auto_uid_number_mechanism. Por favor soluciona
                                  este problema.';
$lang['uidpool_not_set'] = 'Has especificado el <tt>auto_uid_number_mechanism</tt> como <tt>uidpool</tt>
                            en tu configuracin para el servidor <b>%s</b>, pero no has especificado el
                            audo_uid_number_uid_pool_dn. Por favor especificalo antes de proceder.';
$lang['uidpool_not_exist'] = 'Parece ser que el uidPool que has especificado en tu configuracin (<tt>%s</tt>)
                              no existe.';
$lang['specified_uidpool'] = 'Has especificado el <tt>auto_uid_number_mechanism</tt> como <tt>search</tt> en tu
                              configuracin para el servidor <b>%s</b>, pero no has especificado el
                              <tt>auto_uid_number_search_base</tt>. Por favor especificalo antes de proceder.';
$lang['auto_uid_invalid_value'] = 'Has especificado un valor no vlido para el auto_uid_number_mechanism (<tt>%s</tt>)
                                   en tu configuracin. Solo <tt>uidpool</tt> y <tt>search</tt> son vlidos.
                                   Por favor soluciona este problema.';
$lang['error_auth_type_config'] = 'Error: Tienes un error en tu archivo de configuracin. Los dos nicos valores aceptados para
                                    \'auth_type\' en la seccin $servers son \'config\' y \'form\'. Tu has puesto \'%s\',
                                    el cual no est aceptado. ';
$lang['php_install_not_supports_tls'] = 'Tu instalacin de PHP no soporta TLS';
$lang['could_not_start_tls'] = 'No he podido iniciar el TLS.<br />Revisa tu configuracin del servidor LDAP.';
$lang['auth_type_not_valid'] = 'Tienes un error en el archivo de configuracin. auth_type de %s no es vlido.';
$lang['ldap_said'] = '<b>LDAP dijo</b>: %s<br /><br />';
$lang['ferror_error'] = 'Error';
$lang['fbrowse'] = 'mostrar';
$lang['delete_photo'] = 'Borrar foto';
$lang['install_not_support_blowfish'] = 'Tu instalacin de PHP no soporta los tipos de encriptacin blowfish.';
$lang['install_no_mash'] = 'Tu instalacin de PHP no tiene la funcion mhash(). No puedo hacer hash SHA.';
$lang['jpeg_contains_errors'] = 'jpegPhoto contiene errores<br />';
$lang['ferror_number'] = '<b>Error nmero</b>: %s <small>(%s)</small><br /><br />';
$lang['ferror_discription'] = '<b>Descripcin</b>: %s <br /><br />';
$lang['ferror_number_short'] = '<b>Error nmero</b>: %s<br /><br />';
$lang['ferror_discription_short'] = '<b>Descripcin</b>: (no hay descripcin)<br />';
$lang['ferror_submit_bug'] = 'Es un error del phpLDAPadmin? Si as es, por favor <a href=\'%s\'>dnoslo</a>.';
$lang['ferror_unrecognized_num'] = 'Nmero de error desconocido: ';
$lang['ferror_nonfatil_bug'] = '<center><table class=\'notice\'><tr><td colspan=\'2\'><center><img src=\'images/warning.png\' height=\'12\' width=\'13\' />
             <b>Has encontrado un error menor del phpLDAPadmin!</b></td></tr><tr><td>Error:</td><td><b>%s</b> (<b>%s</b>)</td></tr><tr><td>Archivo:</td>
             <td><b>%s</b> lnea <b>%s</b>, caller <b>%s</b></td></tr><tr><td>Versiones:</td><td>PLA: <b>%s</b>, PHP: <b>%s</b>, SAPI: <b>%s</b>
             </td></tr><tr><td>Servidor Web:</td><td><b>%s</b></td></tr><tr><td colspan=\'2\'><center><a target=\'new\' href=\'%s\'>
             Enva este error haciendo click aqu</a>.</center></td></tr></table></center><br />';
$lang['ferror_congrats_found_bug'] = 'Felicidades! Has encontrado un error en el phpLDAPadmin.<br /><br />
	     <table class=\'bug\'>
	     <tr><td>Error:</td><td><b>%s</b></td></tr>
	     <tr><td>Nivel:</td><td><b>%s</b></td></tr>
	     <tr><td>Archivo:</td><td><b>%s</b></td></tr>
	     <tr><td>Lnea:</td><td><b>%s</b></td></tr>
	     <tr><td>Caller:</td><td><b>%s</b></td></tr>
	     <tr><td>Versin PLA:</td><td><b>%s</b></td></tr>
	     <tr><td>Versin PHP:</td><td><b>%s</b></td></tr>
	     <tr><td>PHP SAPI:</td><td><b>%s</b></td></tr>
	     <tr><td>Servidor Web:</td><td><b>%s</b></td></tr>
	     </table>
	     <br />
	     Por favor enva este error haciendo click abajo!';
//ldif_import_form
$lang['import_ldif_file_title'] = 'Importar archivo LDIF';                   
$lang['select_ldif_file'] = 'Selecciona un archivo LDIF:';
$lang['select_ldif_file_proceed'] = 'Proceder &gt;&gt;';

//ldif_import
$lang['add_action'] = 'Aadiendo...';
$lang['delete_action'] = 'Borrando...';
$lang['rename_action'] = 'Renombrando...';
$lang['modify_action'] = 'Modificando...';

$lang['failed'] = 'fallado';
$lang['ldif_parse_error'] = 'Error de parseado LDIF';
$lang['ldif_could_not_add_object'] = 'No he podido aadir el objeto:';
$lang['ldif_could_not_rename_object'] = 'No he podido renombrar el objeto:';
$lang['ldif_could_not_delete_object'] = 'No he podido borrar el objeto:';
$lang['ldif_could_not_modify_object'] = 'No he podido modificar el objeto:';
$lang['ldif_line_number'] = 'Linea Nmero:';
$lang['ldif_line'] = 'Linea:';

?>
